#
# spec file for package pngcheck
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pngcheck
Version:        3.0.3
Release:        2.2
Summary:        PNG file format checker
License:        GPL-2.0-or-later AND HPND
Group:          Productivity/Graphics/Other
URL:            http://www.libpng.org/pub/png/apps/pngcheck.html
Source:         http://www.libpng.org/pub/png/src/pngcheck-%{version}.tar.gz
Patch0:         fixbuild.diff
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
pngcheck verifies the integrity of PNG, JNG and MNG files (by checking the
internal 32-bit CRCs or checksums) and optionally dumps almost all of the
chunk-level information in the image in human-readable form. For example, it
can be used to print the basic stats about an image (dimensions, bit depth,
etc.); to list the color and transparency info in its palette; or to extract
the embedded text annotations. All PNG and JNG chunks are supported, plus
almost all MNG chunks (everything but PAST, DISC, tERm, DROP, DBYK, and
ORDR). This is a command-line program with batch capabilities (e.g.,
``pngcheck *.png'').

%prep
%autosetup -p1

%build
make %{?_smp_mflags} -f Makefile.unx

%install
install -m 755 -d %{buildroot}%{_bindir}
install -m 755 %{name} %{buildroot}%{_bindir}/
install -m 755 pngsplit %{buildroot}%{_bindir}/
install -m 755 png-fix-IDAT-windowsize %{buildroot}%{_bindir}/
install -m 755 -d %{buildroot}%{_mandir}/man1/
install -m 0644 pngcheck.1 %{buildroot}%{_mandir}/man1/

%files
%defattr(-,root,root)
%doc CHANGELOG README gpl/COPYING
%{_bindir}/*
%{_mandir}/man1/%{name}.1.gz

%changelog
* Thu Feb 22 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Dec 13 2021 pgajdos@suse.com
- version update to 3.0.3
  * 20210124 GRR: released version 3.0.1
  * ----------------------
  * 20201217 BB:  fixed a crash bug (and probable vulnerability) in large (MNG)
  * LOOP chunks
  * 20210131 GRR: updated Makefile.mingw32 for modern versions and added
  * Makefile.mingw64 (targets Win64); both are essentially
  * UNTESTED, however!
  * 20210131 GRR: released version 3.0.2
  * ----------------------
  * 20210416 BB:  fixed a divide-by-zero crash bug (and probable vulnerability)
  * in interlaced images with extra compressed data beyond the
  * nominal end of the image data (found by "chiba of topsec alpha
  * lab")
* Mon Dec 28 2020 pgajdos@suse.com
- version update to 3.0.0
  * 20070709 GRR: tweaked color definitions slightly to work better on terminals
  * with white/light backgrounds
  * 20070712 GRR: added Makefile.mingw32
  * 20100504 GRR: fixed DHDR (pre-MNG-1.0) bug identified by Winfried <szukw000@arcor.de>
  * 20170713 GRP: added eXIf support (GRR: added check for II/MM/unknown format)
  * 20201012 BB:  converted static const help/usage-related strings to macros so
  * -Werror=format-security doesn't trigger (Ben Beasley)
  * 20201015 BB:  added (help2man-generated) man pages for all three utils
  * 20201017 GRR: added top-level LICENSE file; fixed various compiler warnings
  * 20201031 GRR: replaced gpl/COPYING (outdated address, references to Library
  * GPL) with https://www.gnu.org/licenses/old-licenses/gpl-2.0.txt
  * (thanks to Ben Beasley for catching that)
  * 20201113 BB:  fixed buffer-overflow vulnerability discovered by "giantbranch
  * of NSFOCUS Security Team"
  * https://bugzilla.redhat.com/show_bug.cgi?id=1897485
  * 20201128 BB:  found and fixed four additional vulnerabilities (null-pointer
  * dereference and three buffer overruns)
  * 20201209 LP:  fixed an off-by-one bug in check_magic() (Lucy Phipps)
  * 20201209 LL:  converted two zlib-version warnings/errors to go to stderr
  * (Lemures Lemniscati, actually from 20180318; forwarded by LP)
  * 20201210 BB:  fixed another buffer-overflow vulnerability discovered by
  * "giantbranch of NSFOCUS Security Team"
  * https://bugzilla.redhat.com/show_bug.cgi?id=1905775
  * 20201212 GRR: removed -f ("force") option due to multiple security issues
- modified patches
  %% fixbuild.diff (refreshed)
- deleted patches
  - pngcheck-CVE-2020-27818.patch (upstreamed)
* Thu Dec  3 2020 pgajdos@suse.com
- security update
- added patches
  fix CVE-2020-27818 [bsc#1179528], global buffer overflow was discovered in check_chunk_name function via crafted pngfile
  + pngcheck-CVE-2020-27818.patch
* Sun Aug  2 2015 mpluskal@suse.com
- Use url for source
- Cleanup spec file with spec-cleaner
* Fri Aug  9 2013 pgajdos@suse.com
- micro spec file cleanup, created *.changes
* Sun Aug 30 2009 opensuse@dstoecker.de
- created 2.3.0
